@@ -16,13 +16,27 @@ static PyMethodDef mod_methods[] = {
 };
 
 /* Python glue */
-PyObjC_MODULE_INIT(_CoreData)
+static struct PyModuleDef mod_module = {
+     PyModuleDef_HEAD_INIT,
+     "_CoreData",
+     NULL,
+     0,
+     mod_methods,
+     NULL,
+     NULL,
+     NULL,
+     NULL};
+
+PyObject* PyInit__CoreData(void);
+
+PyObject* __attribute__((__visibility__("default"))) PyInit__CoreData(void)
 {
     PyObject* m;
-    m = PyObjC_MODULE_CREATE(_CoreData) if (!m) { PyObjC_INITERROR(); }
+    m = PyModule_Create(&mod_module);
+    if (!m) { return NULL; }
 
     if (PyObjC_ImportAPI(m) == -1)
-        PyObjC_INITERROR();
+        return NULL;
 
     /*
      * XXX: This call is here to force some initialisation
@@ -31,5 +45,5 @@ PyObjC_MODULE_INIT(_CoreData)
      */
     [NSManagedObjectContext initialize];
 
-    PyObjC_INITDONE();
+    return m;
 }
